#! /usr/bin/env python
import os
import sys

sys.path.append(os.path.abspath(os.path.dirname(__file__) + '/../'))
from core import scrib


scrib = scrib.scrib('cli', {
	'chatrate': 1.0,
	'maxwords': 30
})
settings = scrib.setcfg()


class ScribCLI:
	"""
	Module to interface console input and output with the Scrib learn
	and reply modules. Allows offline chat with Scrib.
	"""

	def __init__(self, scrib):
		
		# Identify yourself and send default settings
		self.start()

	def start(self):
		scrib.barf('ACT', 'Scrib offline chat!')
		scrib.barf('MSG', 'Talking with %s' % scrib.name)
		# scrib.barf('ACT', 'Type !quit to leave')
		scrib.barf('ACT', 'Enter your name?\033[0m')
		name = raw_input('> ')
		while 1:
			try:
				body = raw_input(name + '> ')
			except (KeyboardInterrupt, EOFError):
				scrib.shutdown()
				return

			# Pass message to scrib
			self.output(scrib.reply(body, reply=True))

	def output(self, message):
		"""
		Output a line of text.
		"""
		if message is not None:
			scrib.barf('DEF', scrib.name + '> \033[0m' + message, time=False)


if __name__ == '__main__':
	try:
		ScribCLI(scrib)
	# Supresses errors that ^c causes
	except SystemExit:
		pass
	# Cleanly exit scrib if ^c detected
	except KeyboardInterrupt:
		scrib.shutdown()
	# Barf if crash.
	except Exception as e:
		scrib.barf('ERR', e.message)
		scrib.shutdown()

	sys.exit()
